@@ -14,7 +14,9 @@ if __name__ == "__main__":
 
     scores = darthvader.sentiment(
         *args,
-        window=3,  # how many days back from up_to to get news from
+        window=1,  # how many days back from up_to to get news from
     )  # latest date to get news from
-
-    pprint(scores)
\ No newline at end of file
+    pprint(scores)
+    print(scores["tesla"]["title"])
+    print(scores["tesla"]["desc"])
+    print(scores["tesla"]["text"])
